@@ -12,7 +12,7 @@
 namespace Monolog\Handler;
 
 use Monolog\Test\TestCase;
-use Monolog\Logger;
+use Monolog\Level;
 use PhpAmqpLib\Message\AMQPMessage;
 
 /**
@@ -39,14 +39,14 @@ class AmqpHandlerTest extends TestCase
 
         $exchange->expects($this->any())
             ->method('publish')
-            ->will($this->returnCallback(function ($message, $routing_key, $flags = 0, $attributes = []) use (&$messages) {
+            ->willReturnCallback(function ($message, $routing_key, $flags = 0, $attributes = []) use (&$messages) {
                 $messages[] = [$message, $routing_key, $flags, $attributes];
-            }))
+            })
         ;
 
         $handler = new AmqpHandler($exchange);
 
-        $record = $this->getRecord(Logger::WARNING, 'test', ['data' => new \stdClass, 'foo' => 34]);
+        $record = $this->getRecord(Level::Warning, 'test', ['data' => new \stdClass, 'foo' => 34]);
 
         $expected = [
             [
@@ -96,14 +96,14 @@ class AmqpHandlerTest extends TestCase
 
         $exchange->expects($this->any())
             ->method('basic_publish')
-            ->will($this->returnCallback(function (AMQPMessage $msg, $exchange = "", $routing_key = "", $mandatory = false, $immediate = false, $ticket = null) use (&$messages) {
+            ->willReturnCallback(function (AMQPMessage $msg, $exchange = "", $routing_key = "", $mandatory = false, $immediate = false, $ticket = null) use (&$messages) {
                 $messages[] = [$msg, $exchange, $routing_key, $mandatory, $immediate, $ticket];
-            }))
+            })
         ;
 
         $handler = new AmqpHandler($exchange, 'log');
 
-        $record = $this->getRecord(Logger::WARNING, 'test', ['data' => new \stdClass, 'foo' => 34]);
+        $record = $this->getRecord(Level::Warning, 'test', ['data' => new \stdClass, 'foo' => 34]);
 
         $expected = [
             [
