@@ -13,7 +13,7 @@ namespace Monolog\Handler;
 
 use Gelf\Message;
 use Monolog\Test\TestCase;
-use Monolog\Logger;
+use Monolog\Level;
 use Monolog\Formatter\GelfMessageFormatter;
 
 class GelfHandlerTest extends TestCase
@@ -51,20 +51,15 @@ class GelfHandlerTest extends TestCase
 
     public function testDebug()
     {
-        $record = $this->getRecord(Logger::DEBUG, "A test debug message");
+        $record = $this->getRecord(Level::Debug, "A test debug message");
         $expectedMessage = new Message();
         $expectedMessage
             ->setLevel(7)
-            ->setShortMessage($record['message'])
-            ->setTimestamp($record['datetime'])
+            ->setAdditional('facility', 'test')
+            ->setShortMessage($record->message)
+            ->setTimestamp($record->datetime)
         ;
 
-        if (self::isGelfVersion1()) {
-            $expectedMessage->setFacility("test");
-        } else {
-            $expectedMessage->setAdditional('facility', "test");
-        }
-
         $messagePublisher = $this->getMessagePublisher();
         $messagePublisher->expects($this->once())
             ->method('publish')
@@ -77,20 +72,15 @@ class GelfHandlerTest extends TestCase
 
     public function testWarning()
     {
-        $record = $this->getRecord(Logger::WARNING, "A test warning message");
+        $record = $this->getRecord(Level::Warning, "A test warning message");
         $expectedMessage = new Message();
         $expectedMessage
             ->setLevel(4)
-            ->setShortMessage($record['message'])
-            ->setTimestamp($record['datetime'])
+            ->setAdditional('facility', 'test')
+            ->setShortMessage($record->message)
+            ->setTimestamp($record->datetime)
         ;
 
-        if (self::isGelfVersion1()) {
-            $expectedMessage->setFacility("test");
-        } else {
-            $expectedMessage->setAdditional('facility', "test");
-        }
-
         $messagePublisher = $this->getMessagePublisher();
         $messagePublisher->expects($this->once())
             ->method('publish')
@@ -103,26 +93,24 @@ class GelfHandlerTest extends TestCase
 
     public function testInjectedGelfMessageFormatter()
     {
-        $record = $this->getRecord(Logger::WARNING, "A test warning message");
-        $record['extra']['blarg'] = 'yep';
-        $record['context']['from'] = 'logger';
+        $record = $this->getRecord(
+            Level::Warning,
+            "A test warning message",
+            extra: ['blarg' => 'yep'],
+            context: ['from' => 'logger'],
+        );
 
         $expectedMessage = new Message();
         $expectedMessage
             ->setLevel(4)
+            ->setAdditional('facility', 'test')
             ->setHost("mysystem")
-            ->setShortMessage($record['message'])
-            ->setTimestamp($record['datetime'])
+            ->setShortMessage($record->message)
+            ->setTimestamp($record->datetime)
             ->setAdditional("EXTblarg", 'yep')
             ->setAdditional("CTXfrom", 'logger')
         ;
 
-        if (self::isGelfVersion1()) {
-            $expectedMessage->setFacility("test");
-        } else {
-            $expectedMessage->setAdditional('facility', "test");
-        }
-
         $messagePublisher = $this->getMessagePublisher();
         $messagePublisher->expects($this->once())
             ->method('publish')
@@ -132,9 +120,4 @@ class GelfHandlerTest extends TestCase
         $handler->setFormatter(new GelfMessageFormatter('mysystem', 'EXT', 'CTX'));
         $handler->handle($record);
     }
-
-    private static function isGelfVersion1()
-    {
-        return method_exists(Message::class, 'setFacility');
-    }
 }
