@@ -12,23 +12,22 @@
 namespace Monolog\Handler;
 
 use Monolog\Test\TestCase;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\MockObject\MockObject;
 
 /**
  * @author Alexey Karapetov <alexey@karapetov.com>
  */
 class HandlerWrapperTest extends TestCase
 {
-    /**
-     * @var HandlerWrapper
-     */
-    private $wrapper;
+    private HandlerWrapper $wrapper;
 
-    private $handler;
+    private HandlerInterface&MockObject $handler;
 
     public function setUp(): void
     {
         parent::setUp();
-        $this->handler = $this->createMock('Monolog\\Handler\\HandlerInterface');
+        $this->handler = $this->createMock(HandlerInterface::class);
         $this->wrapper = new HandlerWrapper($this->handler);
     }
 
@@ -37,12 +36,10 @@ class HandlerWrapperTest extends TestCase
         parent::tearDown();
 
         unset($this->wrapper);
+        unset($this->handler);
     }
 
-    /**
-     * @return array
-     */
-    public function trueFalseDataProvider()
+    public static function trueFalseDataProvider(): array
     {
         return [
             [true],
@@ -50,11 +47,8 @@ class HandlerWrapperTest extends TestCase
         ];
     }
 
-    /**
-     * @param $result
-     * @dataProvider trueFalseDataProvider
-     */
-    public function testIsHandling($result)
+    #[DataProvider('trueFalseDataProvider')]
+    public function testIsHandling(bool $result)
     {
         $record = $this->getRecord();
         $this->handler->expects($this->once())
@@ -65,11 +59,8 @@ class HandlerWrapperTest extends TestCase
         $this->assertEquals($result, $this->wrapper->isHandling($record));
     }
 
-    /**
-     * @param $result
-     * @dataProvider trueFalseDataProvider
-     */
-    public function testHandle($result)
+    #[DataProvider('trueFalseDataProvider')]
+    public function testHandle(bool $result)
     {
         $record = $this->getRecord();
         $this->handler->expects($this->once())
@@ -80,11 +71,8 @@ class HandlerWrapperTest extends TestCase
         $this->assertEquals($result, $this->wrapper->handle($record));
     }
 
-    /**
-     * @param $result
-     * @dataProvider trueFalseDataProvider
-     */
-    public function testHandleBatch($result)
+    #[DataProvider('trueFalseDataProvider')]
+    public function testHandleBatch(bool $result)
     {
         $records = $this->getMultipleRecords();
         $this->handler->expects($this->once())
