@@ -12,7 +12,7 @@
 namespace Monolog\Handler;
 
 use Monolog\Test\TestCase;
-use Monolog\Logger;
+use Monolog\Level;
 
 /**
  * @covers Monolog\Handler\NullHandler::handle
@@ -27,18 +27,18 @@ class NullHandlerTest extends TestCase
 
     public function testHandleLowerLevelRecord()
     {
-        $handler = new NullHandler(Logger::WARNING);
-        $this->assertFalse($handler->handle($this->getRecord(Logger::DEBUG)));
+        $handler = new NullHandler(Level::Warning);
+        $this->assertFalse($handler->handle($this->getRecord(Level::Debug)));
     }
 
     public function testSerializeRestorePrivate()
     {
-        $handler = new NullHandler(Logger::WARNING);
-        self::assertFalse($handler->handle($this->getRecord(Logger::DEBUG)));
-        self::assertTrue($handler->handle($this->getRecord(Logger::WARNING)));
+        $handler = new NullHandler(Level::Warning);
+        self::assertFalse($handler->handle($this->getRecord(Level::Debug)));
+        self::assertTrue($handler->handle($this->getRecord(Level::Warning)));
 
         $handler = unserialize(serialize($handler));
-        self::assertFalse($handler->handle($this->getRecord(Logger::DEBUG)));
-        self::assertTrue($handler->handle($this->getRecord(Logger::WARNING)));
+        self::assertFalse($handler->handle($this->getRecord(Level::Debug)));
+        self::assertTrue($handler->handle($this->getRecord(Level::Warning)));
     }
 }
