@@ -13,12 +13,15 @@ namespace Monolog\Handler;
 
 use Exception;
 use Monolog\ErrorHandler;
+use Monolog\Level;
 use Monolog\Logger;
 use Monolog\Test\TestCase;
 use PhpConsole\Connector;
 use PhpConsole\Dispatcher\Debug as DebugDispatcher;
 use PhpConsole\Dispatcher\Errors as ErrorDispatcher;
 use PhpConsole\Handler as VendorPhpConsoleHandler;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\WithoutErrorHandler;
 use PHPUnit\Framework\MockObject\MockObject;
 
 /**
@@ -27,12 +30,9 @@ use PHPUnit\Framework\MockObject\MockObject;
  */
 class PHPConsoleHandlerTest extends TestCase
 {
-    /** @var  Connector|MockObject */
-    protected $connector;
-    /** @var  DebugDispatcher|MockObject */
-    protected $debugDispatcher;
-    /** @var  ErrorDispatcher|MockObject */
-    protected $errorDispatcher;
+    protected Connector&MockObject $connector;
+    protected DebugDispatcher&MockObject $debugDispatcher;
+    protected ErrorDispatcher&MockObject $errorDispatcher;
 
     protected function setUp(): void
     {
@@ -101,7 +101,7 @@ class PHPConsoleHandlerTest extends TestCase
 
         $connector->expects($this->any())
             ->method('isActiveClient')
-            ->will($this->returnValue(true));
+            ->willReturn(true);
 
         return $connector;
     }
@@ -114,7 +114,7 @@ class PHPConsoleHandlerTest extends TestCase
         return $options[$name];
     }
 
-    protected function initLogger($handlerOptions = [], $level = Logger::DEBUG)
+    protected function initLogger($handlerOptions = [], $level = Level::Debug)
     {
         return new Logger('test', [
             new PHPConsoleHandler($handlerOptions, $this->connector, $level),
@@ -144,7 +144,7 @@ class PHPConsoleHandlerTest extends TestCase
         $message = 'test';
         $tag = 'tag';
         $context = [$tag, 'custom' => mt_rand()];
-        $expectedMessage = $message . ' ' . json_encode(array_slice($context, 1));
+        $expectedMessage = $message . ' ' . json_encode(\array_slice($context, 1));
         $this->debugDispatcher->expects($this->once())->method('dispatchDebug')->with(
             $this->equalTo($expectedMessage),
             $this->equalTo($tag)
@@ -170,6 +170,7 @@ class PHPConsoleHandlerTest extends TestCase
         }
     }
 
+    #[WithoutErrorHandler]
     public function testError($classesPartialsTraceIgnore = null)
     {
         $code = E_USER_NOTICE;
@@ -183,9 +184,12 @@ class PHPConsoleHandlerTest extends TestCase
             $this->equalTo($line),
             $classesPartialsTraceIgnore ?: $this->equalTo($this->getHandlerDefaultOption('classesPartialsTraceIgnore'))
         );
-        $errorHandler = ErrorHandler::register($this->initLogger($classesPartialsTraceIgnore ? ['classesPartialsTraceIgnore' => $classesPartialsTraceIgnore] : []), false);
+        $errorHandler = ErrorHandler::register($this->initLogger($classesPartialsTraceIgnore ? ['classesPartialsTraceIgnore' => $classesPartialsTraceIgnore] : []), false, false);
         $errorHandler->registerErrorHandler([], false, E_USER_WARNING);
-        $errorHandler->handleError($code, $message, $file, $line);
+        $reflMethod = new \ReflectionMethod($errorHandler, 'handleError');
+        $reflMethod->invoke($errorHandler, $code, $message, $file, $line);
+
+        restore_error_handler();
     }
 
     public function testException()
@@ -197,7 +201,7 @@ class PHPConsoleHandlerTest extends TestCase
         $handler = $this->initLogger();
         $handler->log(
             \Psr\Log\LogLevel::ERROR,
-            sprintf('Uncaught Exception %s: "%s" at %s line %s', get_class($e), $e->getMessage(), $e->getFile(), $e->getLine()),
+            sprintf('Uncaught Exception %s: "%s" at %s line %s', \get_class($e), $e->getMessage(), $e->getFile(), $e->getLine()),
             ['exception' => $e]
         );
     }
@@ -215,11 +219,6 @@ class PHPConsoleHandlerTest extends TestCase
         $this->initLogger(['enabled' => false])->debug('test');
     }
 
-    public function testOptionClassesPartialsTraceIgnore()
-    {
-        $this->testError(['Class', 'Namespace\\']);
-    }
-
     public function testOptionDebugTagsKeysInContext()
     {
         $this->testDebugTags(['key1', 'key2']);
@@ -232,6 +231,11 @@ class PHPConsoleHandlerTest extends TestCase
         }));
         $this->assertEquals([VendorPhpConsoleHandler::getInstance(), 'handleException'], set_exception_handler(function () {
         }));
+
+        restore_exception_handler();
+        restore_error_handler();
+        restore_exception_handler();
+        restore_error_handler();
     }
 
     public static function provideConnectorMethodsOptionsSets()
@@ -247,9 +251,7 @@ class PHPConsoleHandlerTest extends TestCase
         ];
     }
 
-    /**
-     * @dataProvider provideConnectorMethodsOptionsSets
-     */
+    #[DataProvider('provideConnectorMethodsOptionsSets')]
     public function testOptionCallsConnectorMethod($option, $method, $value, $isArgument = true)
     {
         $expectCall = $this->connector->expects($this->once())->method($method);
@@ -276,9 +278,7 @@ class PHPConsoleHandlerTest extends TestCase
         ];
     }
 
-    /**
-     * @dataProvider provideDumperOptionsValues
-     */
+    #[DataProvider('provideDumperOptionsValues')]
     public function testDumperOptions($option, $dumperProperty, $value)
     {
         new PHPConsoleHandler([$option => $value], $this->connector);
