@@ -13,13 +13,14 @@ namespace Monolog\Handler;
 
 use InvalidArgumentException;
 use Monolog\Test\TestCase;
+use PHPUnit\Framework\Attributes\DataProvider;
 
 /**
  * @covers Monolog\Handler\RotatingFileHandler
  */
 class RotatingFileHandlerTest extends TestCase
 {
-    private $lastError;
+    private array|null $lastError = null;
 
     public function setUp(): void
     {
@@ -47,7 +48,7 @@ class RotatingFileHandlerTest extends TestCase
             unlink($file);
         }
 
-        if ('testRotationWithFolderByDate' === $this->getName(false)) {
+        if ('testRotationWithFolderByDate' === $this->name()) {
             foreach (glob(__DIR__.'/Fixtures/[0-9]*') as $folder) {
                 $this->rrmdir($folder);
             }
@@ -58,12 +59,13 @@ class RotatingFileHandlerTest extends TestCase
         unset($this->lastError);
     }
 
-    private function rrmdir($directory) {
+    private function rrmdir($directory)
+    {
         if (! is_dir($directory)) {
             throw new InvalidArgumentException("$directory must be a directory");
         }
 
-        if (substr($directory, strlen($directory) - 1, 1) !== '/') {
+        if (substr($directory, \strlen($directory) - 1, 1) !== '/') {
             $directory .= '/';
         }
 
@@ -106,9 +108,7 @@ class RotatingFileHandlerTest extends TestCase
         $this->assertEquals('test', file_get_contents($log));
     }
 
-    /**
-     * @dataProvider rotationTests
-     */
+    #[DataProvider('rotationTests')]
     public function testRotation($createFile, $dateFormat, $timeCallback)
     {
         touch($old1 = __DIR__.'/Fixtures/foo-'.date($dateFormat, $timeCallback(-1)).'.rot');
@@ -137,7 +137,7 @@ class RotatingFileHandlerTest extends TestCase
         $this->assertEquals('test', file_get_contents($log));
     }
 
-    public function rotationTests()
+    public static function rotationTests()
     {
         $now = time();
         $dayCallback = function ($ago) use ($now) {
@@ -170,15 +170,13 @@ class RotatingFileHandlerTest extends TestCase
 
     private function createDeep($file)
     {
-        mkdir(dirname($file), 0777, true);
+        mkdir(\dirname($file), 0777, true);
         touch($file);
 
         return $file;
     }
 
-    /**
-     * @dataProvider rotationWithFolderByDateTests
-     */
+    #[DataProvider('rotationWithFolderByDateTests')]
     public function testRotationWithFolderByDate($createFile, $dateFormat, $timeCallback)
     {
         $old1 = $this->createDeep(__DIR__.'/Fixtures/'.date($dateFormat, $timeCallback(-1)).'/foo.rot');
@@ -207,7 +205,7 @@ class RotatingFileHandlerTest extends TestCase
         $this->assertEquals('test', file_get_contents($log));
     }
 
-    public function rotationWithFolderByDateTests()
+    public static function rotationWithFolderByDateTests()
     {
         $now = time();
         $dayCallback = function ($ago) use ($now) {
@@ -238,9 +236,7 @@ class RotatingFileHandlerTest extends TestCase
         ];
     }
 
-    /**
-     * @dataProvider dateFormatProvider
-     */
+    #[DataProvider('dateFormatProvider')]
     public function testAllowOnlyFixedDefinedDateFormats($dateFormat, $valid)
     {
         $handler = new RotatingFileHandler(__DIR__.'/Fixtures/foo.rot', 2);
@@ -252,7 +248,7 @@ class RotatingFileHandlerTest extends TestCase
         $this->assertTrue(true);
     }
 
-    public function dateFormatProvider()
+    public static function dateFormatProvider()
     {
         return [
             [RotatingFileHandler::FILE_PER_DAY, true],
@@ -279,9 +275,7 @@ class RotatingFileHandlerTest extends TestCase
         ];
     }
 
-    /**
-     * @dataProvider filenameFormatProvider
-     */
+    #[DataProvider('filenameFormatProvider')]
     public function testDisallowFilenameFormatsWithoutDate($filenameFormat, $valid)
     {
         $handler = new RotatingFileHandler(__DIR__.'/Fixtures/foo.rot', 2);
@@ -293,7 +287,7 @@ class RotatingFileHandlerTest extends TestCase
         $handler->setFilenameFormat($filenameFormat, RotatingFileHandler::FILE_PER_DAY);
     }
 
-    public function filenameFormatProvider()
+    public static function filenameFormatProvider()
     {
         return [
             ['{filename}', false],
@@ -307,9 +301,7 @@ class RotatingFileHandlerTest extends TestCase
         ];
     }
 
-    /**
-     * @dataProvider rotationWhenSimilarFilesExistTests
-     */
+    #[DataProvider('rotationWhenSimilarFilesExistTests')]
     public function testRotationWhenSimilarFileNamesExist($dateFormat)
     {
         touch($old1 = __DIR__.'/Fixtures/foo-foo-'.date($dateFormat).'.rot');
@@ -326,18 +318,18 @@ class RotatingFileHandlerTest extends TestCase
         $this->assertTrue(file_exists($log));
     }
 
-    public function rotationWhenSimilarFilesExistTests()
+    public static function rotationWhenSimilarFilesExistTests()
     {
-        return array(
+        return [
             'Rotation is triggered when the file of the current day is not present but similar exists'
-                => array(RotatingFileHandler::FILE_PER_DAY),
+                => [RotatingFileHandler::FILE_PER_DAY],
 
             'Rotation is triggered when the file of the current month is not present but similar exists'
-                => array(RotatingFileHandler::FILE_PER_MONTH),
+                => [RotatingFileHandler::FILE_PER_MONTH],
 
             'Rotation is triggered when the file of the current year is not present but similar exists'
-                => array(RotatingFileHandler::FILE_PER_YEAR),
-        );
+                => [RotatingFileHandler::FILE_PER_YEAR],
+        ];
     }
 
     public function testReuseCurrentFile()
