@@ -25,7 +25,7 @@ class SamplingHandlerTest extends TestCase
         for ($i = 0; $i < 10000; $i++) {
             $handler->handle($this->getRecord());
         }
-        $count = count($testHandler->getRecords());
+        $count = \count($testHandler->getRecords());
         // $count should be half of 10k, so between 4k and 6k
         $this->assertLessThan(6000, $count);
         $this->assertGreaterThan(4000, $count);
