@@ -12,7 +12,7 @@
 namespace Monolog\Handler;
 
 use Monolog\Test\TestCase;
-use Monolog\Logger;
+use Monolog\Level;
 use PHPUnit\Framework\MockObject\MockObject;
 
 /**
@@ -20,10 +20,7 @@ use PHPUnit\Framework\MockObject\MockObject;
  */
 class SocketHandlerTest extends TestCase
 {
-    /**
-     * @var \Monolog\Handler\SocketHandler|MockObject
-     */
-    private $handler;
+    private SocketHandler&MockObject $handler;
 
     /**
      * @var resource
@@ -35,64 +32,65 @@ class SocketHandlerTest extends TestCase
         parent::tearDown();
 
         unset($this->res);
+        unset($this->handler);
     }
 
     public function testInvalidHostname()
     {
         $this->expectException(\UnexpectedValueException::class);
 
-        $this->createHandler('garbage://here');
-        $this->writeRecord('data');
+        $handler = $this->createHandler('garbage://here');
+        $handler->handle($this->getRecord(Level::Warning, 'data'));
     }
 
     public function testBadConnectionTimeout()
     {
         $this->expectException(\InvalidArgumentException::class);
 
-        $this->createHandler('localhost:1234');
-        $this->handler->setConnectionTimeout(-1);
+        $handler = $this->createHandler('localhost:1234');
+        $handler->setConnectionTimeout(-1);
     }
 
     public function testSetConnectionTimeout()
     {
-        $this->createHandler('localhost:1234');
-        $this->handler->setConnectionTimeout(10.1);
-        $this->assertEquals(10.1, $this->handler->getConnectionTimeout());
+        $handler = $this->createHandler('localhost:1234');
+        $handler->setConnectionTimeout(10.1);
+        $this->assertEquals(10.1, $handler->getConnectionTimeout());
     }
 
     public function testBadTimeout()
     {
         $this->expectException(\InvalidArgumentException::class);
 
-        $this->createHandler('localhost:1234');
-        $this->handler->setTimeout(-1);
+        $handler = $this->createHandler('localhost:1234');
+        $handler->setTimeout(-1);
     }
 
     public function testSetTimeout()
     {
-        $this->createHandler('localhost:1234');
-        $this->handler->setTimeout(10.25);
-        $this->assertEquals(10.25, $this->handler->getTimeout());
+        $handler = $this->createHandler('localhost:1234');
+        $handler->setTimeout(10.25);
+        $this->assertEquals(10.25, $handler->getTimeout());
     }
 
     public function testSetWritingTimeout()
     {
-        $this->createHandler('localhost:1234');
-        $this->handler->setWritingTimeout(10.25);
-        $this->assertEquals(10.25, $this->handler->getWritingTimeout());
+        $handler = $this->createHandler('localhost:1234');
+        $handler->setWritingTimeout(10.25);
+        $this->assertEquals(10.25, $handler->getWritingTimeout());
     }
 
     public function testSetChunkSize()
     {
-        $this->createHandler('localhost:1234');
-        $this->handler->setChunkSize(1025);
-        $this->assertEquals(1025, $this->handler->getChunkSize());
+        $handler = $this->createHandler('localhost:1234');
+        $handler->setChunkSize(1025);
+        $this->assertEquals(1025, $handler->getChunkSize());
     }
 
     public function testSetConnectionString()
     {
-        $this->createHandler('tcp://localhost:9090');
-        $this->assertEquals('tcp://localhost:9090', $this->handler->getConnectionString());
+        $handler = $this->createHandler('tcp://localhost:9090');
+        $this->assertEquals('tcp://localhost:9090', $handler->getConnectionString());
     }
 
     public function testExceptionIsThrownOnFsockopenError()
@@ -100,7 +98,7 @@ class SocketHandlerTest extends TestCase
         $this->setMockHandler(['fsockopen']);
         $this->handler->expects($this->once())
             ->method('fsockopen')
-            ->will($this->returnValue(false));
+            ->willReturn(false);
 
         $this->expectException(\UnexpectedValueException::class);
 
@@ -112,7 +110,7 @@ class SocketHandlerTest extends TestCase
         $this->setMockHandler(['pfsockopen']);
         $this->handler->expects($this->once())
             ->method('pfsockopen')
-            ->will($this->returnValue(false));
+            ->willReturn(false);
 
         $this->handler->setPersistent(true);
 
@@ -126,7 +124,7 @@ class SocketHandlerTest extends TestCase
         $this->setMockHandler(['streamSetTimeout']);
         $this->handler->expects($this->once())
             ->method('streamSetTimeout')
-            ->will($this->returnValue(false));
+            ->willReturn(false);
 
         $this->expectException(\UnexpectedValueException::class);
 
@@ -135,11 +133,11 @@ class SocketHandlerTest extends TestCase
 
     public function testExceptionIsThrownIfCannotSetChunkSize()
     {
-        $this->setMockHandler(array('streamSetChunkSize'));
+        $this->setMockHandler(['streamSetChunkSize']);
         $this->handler->setChunkSize(8192);
         $this->handler->expects($this->once())
             ->method('streamSetChunkSize')
-            ->will($this->returnValue(false));
+            ->willReturn(false);
 
         $this->expectException(\UnexpectedValueException::class);
 
@@ -161,7 +159,7 @@ class SocketHandlerTest extends TestCase
 
         $this->handler->expects($this->exactly(2))
             ->method('fwrite')
-            ->will($this->returnCallback($callback));
+            ->willReturnCallback($callback);
 
         $this->expectException(\RuntimeException::class);
 
@@ -183,10 +181,10 @@ class SocketHandlerTest extends TestCase
 
         $this->handler->expects($this->exactly(1))
             ->method('fwrite')
-            ->will($this->returnCallback($callback));
+            ->willReturnCallback($callback);
         $this->handler->expects($this->exactly(1))
             ->method('streamGetMetadata')
-            ->will($this->returnValue(['timed_out' => true]));
+            ->willReturn(['timed_out' => true]);
 
         $this->expectException(\RuntimeException::class);
 
@@ -201,15 +199,15 @@ class SocketHandlerTest extends TestCase
         $callback = function ($string) use ($res) {
             fclose($res);
 
-            return strlen('Hello');
+            return \strlen('Hello');
         };
 
         $this->handler->expects($this->exactly(1))
             ->method('fwrite')
-            ->will($this->returnCallback($callback));
+            ->willReturnCallback($callback);
         $this->handler->expects($this->exactly(1))
             ->method('streamGetMetadata')
-            ->will($this->returnValue(['timed_out' => false]));
+            ->willReturn(['timed_out' => false]);
 
         $this->expectException(\RuntimeException::class);
 
@@ -241,7 +239,7 @@ class SocketHandlerTest extends TestCase
 
         $this->handler->expects($this->exactly(2))
             ->method('fwrite')
-            ->will($this->returnCallback($callback));
+            ->willReturnCallback($callback);
 
         $this->writeRecord('Hello world');
     }
@@ -252,7 +250,7 @@ class SocketHandlerTest extends TestCase
         $this->writeRecord('Hello world');
         $this->assertIsResource($this->res);
         $this->handler->close();
-        $this->assertFalse(is_resource($this->res), "Expected resource to be closed after closing handler");
+        $this->assertFalse(\is_resource($this->res), "Expected resource to be closed after closing handler");
     }
 
     public function testCloseDoesNotClosePersistentSocket()
@@ -260,9 +258,9 @@ class SocketHandlerTest extends TestCase
         $this->setMockHandler();
         $this->handler->setPersistent(true);
         $this->writeRecord('Hello world');
-        $this->assertTrue(is_resource($this->res));
+        $this->assertTrue(\is_resource($this->res));
         $this->handler->close();
-        $this->assertTrue(is_resource($this->res));
+        $this->assertTrue(\is_resource($this->res));
     }
 
     public function testAvoidInfiniteLoopWhenNoDataIsWrittenForAWritingTimeoutSeconds()
@@ -271,11 +269,11 @@ class SocketHandlerTest extends TestCase
 
         $this->handler->expects($this->any())
             ->method('fwrite')
-            ->will($this->returnValue(0));
+            ->willReturn(0);
 
         $this->handler->expects($this->any())
             ->method('streamGetMetadata')
-            ->will($this->returnValue(['timed_out' => false]));
+            ->willReturn(['timed_out' => false]);
 
         $this->handler->setWritingTimeout(1);
 
@@ -284,15 +282,17 @@ class SocketHandlerTest extends TestCase
         $this->writeRecord('Hello world');
     }
 
-    private function createHandler($connectionString)
+    private function createHandler(string $connectionString): SocketHandler
     {
-        $this->handler = new SocketHandler($connectionString);
-        $this->handler->setFormatter($this->getIdentityFormatter());
+        $handler = new SocketHandler($connectionString);
+        $handler->setFormatter($this->getIdentityFormatter());
+
+        return $handler;
     }
 
     private function writeRecord($string)
     {
-        $this->handler->handle($this->getRecord(Logger::WARNING, $string));
+        $this->handler->handle($this->getRecord(Level::Warning, $string));
     }
 
     private function setMockHandler(array $methods = [])
@@ -309,28 +309,28 @@ class SocketHandlerTest extends TestCase
             ->setConstructorArgs(['localhost:1234'])
             ->getMock();
 
-        if (!in_array('fsockopen', $methods)) {
+        if (!\in_array('fsockopen', $methods)) {
             $this->handler->expects($this->any())
                 ->method('fsockopen')
-                ->will($this->returnValue($this->res));
+                ->willReturn($this->res);
         }
 
-        if (!in_array('pfsockopen', $methods)) {
+        if (!\in_array('pfsockopen', $methods)) {
             $this->handler->expects($this->any())
                 ->method('pfsockopen')
-                ->will($this->returnValue($this->res));
+                ->willReturn($this->res);
         }
 
-        if (!in_array('streamSetTimeout', $methods)) {
+        if (!\in_array('streamSetTimeout', $methods)) {
             $this->handler->expects($this->any())
                 ->method('streamSetTimeout')
-                ->will($this->returnValue(true));
+                ->willReturn(true);
         }
 
-        if (!in_array('streamSetChunkSize', $methods)) {
+        if (!\in_array('streamSetChunkSize', $methods)) {
             $this->handler->expects($this->any())
                 ->method('streamSetChunkSize')
-                ->will($this->returnValue(8192));
+                ->willReturn(8192);
         }
 
         $this->handler->setFormatter($this->getIdentityFormatter());
