@@ -11,12 +11,19 @@
 
 namespace Monolog\Handler;
 
-use Monolog\Handler\StreamHandler;
 use Monolog\Test\TestCase;
-use Monolog\Logger;
+use Monolog\Level;
+use PHPUnit\Framework\Attributes\DataProvider;
 
 class StreamHandlerTest extends TestCase
 {
+    public function tearDown(): void
+    {
+        parent::tearDown();
+
+        @unlink(__DIR__.'/test.log');
+    }
+
     /**
      * @covers Monolog\Handler\StreamHandler::__construct
      * @covers Monolog\Handler\StreamHandler::write
@@ -26,9 +33,9 @@ class StreamHandlerTest extends TestCase
         $handle = fopen('php://memory', 'a+');
         $handler = new StreamHandler($handle);
         $handler->setFormatter($this->getIdentityFormatter());
-        $handler->handle($this->getRecord(Logger::WARNING, 'test'));
-        $handler->handle($this->getRecord(Logger::WARNING, 'test2'));
-        $handler->handle($this->getRecord(Logger::WARNING, 'test3'));
+        $handler->handle($this->getRecord(Level::Warning, 'test'));
+        $handler->handle($this->getRecord(Level::Warning, 'test2'));
+        $handler->handle($this->getRecord(Level::Warning, 'test3'));
         fseek($handle, 0);
         $this->assertEquals('testtest2test3', fread($handle, 100));
     }
@@ -40,9 +47,9 @@ class StreamHandlerTest extends TestCase
     {
         $handle = fopen('php://memory', 'a+');
         $handler = new StreamHandler($handle);
-        $this->assertTrue(is_resource($handle));
+        $this->assertTrue(\is_resource($handle));
         $handler->close();
-        $this->assertTrue(is_resource($handle));
+        $this->assertTrue(\is_resource($handle));
     }
 
     /**
@@ -51,12 +58,12 @@ class StreamHandlerTest extends TestCase
     public function testClose()
     {
         $handler = new StreamHandler('php://memory');
-        $handler->handle($this->getRecord(Logger::WARNING, 'test'));
+        $handler->handle($this->getRecord(Level::Warning, 'test'));
         $stream = $handler->getStream();
 
-        $this->assertTrue(is_resource($stream));
+        $this->assertTrue(\is_resource($stream));
         $handler->close();
-        $this->assertFalse(is_resource($stream));
+        $this->assertFalse(\is_resource($stream));
     }
 
     /**
@@ -66,20 +73,20 @@ class StreamHandlerTest extends TestCase
     public function testSerialization()
     {
         $handler = new StreamHandler('php://memory');
-        $handler->handle($this->getRecord(Logger::WARNING, 'testfoo'));
+        $handler->handle($this->getRecord(Level::Warning, 'testfoo'));
         $stream = $handler->getStream();
 
-        $this->assertTrue(is_resource($stream));
+        $this->assertTrue(\is_resource($stream));
         fseek($stream, 0);
         $this->assertStringContainsString('testfoo', stream_get_contents($stream));
         $serialized = serialize($handler);
-        $this->assertFalse(is_resource($stream));
+        $this->assertFalse(\is_resource($stream));
 
         $handler = unserialize($serialized);
-        $handler->handle($this->getRecord(Logger::WARNING, 'testbar'));
+        $handler->handle($this->getRecord(Level::Warning, 'testbar'));
         $stream = $handler->getStream();
 
-        $this->assertTrue(is_resource($stream));
+        $this->assertTrue(\is_resource($stream));
         fseek($stream, 0);
         $contents = stream_get_contents($stream);
         $this->assertStringNotContainsString('testfoo', $contents);
@@ -102,7 +109,7 @@ class StreamHandlerTest extends TestCase
     public function testWriteLocking()
     {
         $temp = sys_get_temp_dir() . DIRECTORY_SEPARATOR . 'monolog_locked_log';
-        $handler = new StreamHandler($temp, Logger::DEBUG, true, null, true);
+        $handler = new StreamHandler($temp, Level::Debug, true, null, true);
         $handler->handle($this->getRecord());
     }
 
@@ -118,7 +125,7 @@ class StreamHandlerTest extends TestCase
         $handler->handle($this->getRecord());
     }
 
-    public function invalidArgumentProvider()
+    public static function invalidArgumentProvider()
     {
         return [
             [1],
@@ -128,9 +135,9 @@ class StreamHandlerTest extends TestCase
     }
 
     /**
-     * @dataProvider invalidArgumentProvider
      * @covers Monolog\Handler\StreamHandler::__construct
      */
+    #[DataProvider('invalidArgumentProvider')]
     public function testWriteInvalidArgument($invalidArgument)
     {
         $this->expectException(\InvalidArgumentException::class);
@@ -166,9 +173,10 @@ STRING;
         $this->expectExceptionMessage(($majorVersion >= 8) ? $php8xMessage : $php7xMessage);
 
         $handler = new StreamHandler('bogus://url');
-        $record = $this->getRecord();
-        $record['context'] = ['foo' => 'bar'];
-        $record['extra'] = [1, 2, 3];
+        $record = $this->getRecord(
+            context: ['foo' => 'bar'],
+            extra: [1, 2, 3],
+        );
         $handler->handle($record);
     }
 
@@ -204,14 +212,71 @@ STRING;
         $handler->handle($this->getRecord());
     }
 
+    /**
+     * @covers Monolog\Handler\StreamHandler::write
+     */
+    public function testWriteErrorDuringWriteRetriesWithClose()
+    {
+        $handler = $this->getMockBuilder(StreamHandler::class)
+            ->onlyMethods(['streamWrite'])
+            ->setConstructorArgs(['file://'.sys_get_temp_dir().'/bar/'.rand(0, 10000).DIRECTORY_SEPARATOR.rand(0, 10000)])
+            ->getMock();
+
+        $refs = [];
+        $handler->expects($this->exactly(2))
+            ->method('streamWrite')
+            ->willReturnCallback(function ($stream) use (&$refs) {
+                $refs[] = $stream;
+                if (\count($refs) === 2) {
+                    self::assertNotSame($stream, $refs[0]);
+                }
+                if (\count($refs) === 1) {
+                    trigger_error('fwrite(): Write of 378 bytes failed with errno=32 Broken pipe', E_USER_ERROR);
+                }
+            });
+
+        $handler->handle($this->getRecord());
+        if (method_exists($this, 'assertIsClosedResource')) {
+            self::assertIsClosedResource($refs[0]);
+            self::assertIsResource($refs[1]);
+        }
+    }
+
+    /**
+     * @covers Monolog\Handler\StreamHandler::write
+     */
+    public function testWriteErrorDuringWriteRetriesButThrowsIfStillFails()
+    {
+        $handler = $this->getMockBuilder(StreamHandler::class)
+            ->onlyMethods(['streamWrite'])
+            ->setConstructorArgs(['file://'.sys_get_temp_dir().'/bar/'.rand(0, 10000).DIRECTORY_SEPARATOR.rand(0, 10000)])
+            ->getMock();
+
+        $refs = [];
+        $handler->expects($this->exactly(2))
+            ->method('streamWrite')
+            ->willReturnCallback(function ($stream) use (&$refs) {
+                $refs[] = $stream;
+                if (\count($refs) === 2) {
+                    self::assertNotSame($stream, $refs[0]);
+                }
+                trigger_error('fwrite(): Write of 378 bytes failed with errno=32 Broken pipe', E_USER_ERROR);
+            });
+
+        self::expectException(\UnexpectedValueException::class);
+        self::expectExceptionMessage('Writing to the log file failed: Write of 378 bytes failed with errno=32 Broken pipe
+The exception occurred while attempting to log: test');
+        $handler->handle($this->getRecord());
+    }
+
     /**
      * @covers Monolog\Handler\StreamHandler::__construct
      * @covers Monolog\Handler\StreamHandler::write
-     * @dataProvider provideNonExistingAndNotCreatablePath
      */
+    #[DataProvider('provideNonExistingAndNotCreatablePath')]
     public function testWriteNonExistingAndNotCreatablePath($nonExistingAndNotCreatablePath)
     {
-        if (defined('PHP_WINDOWS_VERSION_BUILD')) {
+        if (\defined('PHP_WINDOWS_VERSION_BUILD')) {
             $this->markTestSkipped('Permissions checks can not run on windows');
         }
 
@@ -232,7 +297,7 @@ STRING;
         $handler->handle($this->getRecord());
     }
 
-    public function provideNonExistingAndNotCreatablePath()
+    public static function provideNonExistingAndNotCreatablePath()
     {
         return [
             '/foo/bar/…' => [
@@ -244,7 +309,7 @@ STRING;
         ];
     }
 
-    public function provideMemoryValues()
+    public static function provideMemoryValues()
     {
         return [
             ['1M', (int) (1024*1024/10)],
@@ -259,13 +324,10 @@ STRING;
         ];
     }
 
-    /**
-     * @dataProvider provideMemoryValues
-     * @return void
-     */
-    public function testPreventOOMError($phpMemory, $expectedChunkSize)
+    #[DataProvider('provideMemoryValues')]
+    public function testPreventOOMError($phpMemory, $expectedChunkSize): void
     {
-        $previousValue = ini_set('memory_limit', $phpMemory);
+        $previousValue = @ini_set('memory_limit', $phpMemory);
 
         if ($previousValue === false) {
             $this->markTestSkipped('We could not set a memory limit that would trigger the error.');
@@ -287,10 +349,7 @@ STRING;
         }
     }
 
-    /**
-     * @return void
-     */
-    public function testSimpleOOMPrevention()
+    public function testSimpleOOMPrevention(): void
     {
         $previousValue = ini_set('memory_limit', '2048M');
 
