@@ -22,9 +22,9 @@ class HostnameProcessorTest extends TestCase
     {
         $processor = new HostnameProcessor();
         $record = $processor($this->getRecord());
-        $this->assertArrayHasKey('hostname', $record['extra']);
-        $this->assertIsString($record['extra']['hostname']);
-        $this->assertNotEmpty($record['extra']['hostname']);
-        $this->assertEquals(gethostname(), $record['extra']['hostname']);
+        $this->assertArrayHasKey('hostname', $record->extra);
+        $this->assertIsString($record->extra['hostname']);
+        $this->assertNotEmpty($record->extra['hostname']);
+        $this->assertEquals(gethostname(), $record->extra['hostname']);
     }
 }
