@@ -23,8 +23,8 @@ class MemoryPeakUsageProcessorTest extends TestCase
     {
         $processor = new MemoryPeakUsageProcessor();
         $record = $processor($this->getRecord());
-        $this->assertArrayHasKey('memory_peak_usage', $record['extra']);
-        $this->assertRegExp('#[0-9.]+ (M|K)?B$#', $record['extra']['memory_peak_usage']);
+        $this->assertArrayHasKey('memory_peak_usage', $record->extra);
+        $this->assertMatchesRegularExpression('#[0-9.]+ (M|K)?B$#', $record->extra['memory_peak_usage']);
     }
 
     /**
@@ -35,8 +35,8 @@ class MemoryPeakUsageProcessorTest extends TestCase
     {
         $processor = new MemoryPeakUsageProcessor(true, false);
         $record = $processor($this->getRecord());
-        $this->assertArrayHasKey('memory_peak_usage', $record['extra']);
-        $this->assertIsInt($record['extra']['memory_peak_usage']);
-        $this->assertGreaterThan(0, $record['extra']['memory_peak_usage']);
+        $this->assertArrayHasKey('memory_peak_usage', $record->extra);
+        $this->assertIsInt($record->extra['memory_peak_usage']);
+        $this->assertGreaterThan(0, $record->extra['memory_peak_usage']);
     }
 }
