@@ -22,12 +22,12 @@ class UidProcessorTest extends TestCase
     {
         $processor = new UidProcessor();
         $record = $processor($this->getRecord());
-        $this->assertArrayHasKey('uid', $record['extra']);
+        $this->assertArrayHasKey('uid', $record->extra);
     }
 
     public function testGetUid()
     {
         $processor = new UidProcessor(10);
-        $this->assertEquals(10, strlen($processor->getUid()));
+        $this->assertEquals(10, \strlen($processor->getUid()));
     }
 }
